@@ -3,7 +3,7 @@
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
 # Portable character conversion for Perl.
-# Copyright (C) 2002-2015 Guido Flohr <guido.flohr@cantanea.com>,
+# Copyright (C) 2002-2016 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -341,8 +341,9 @@ to be a consistency checker for UTF-8 data.
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2015, Guido Flohr E<lt>guido.flohr@cantanea.comE<gt>, all
-rights reserved.  See the source code for details.
+Copyright (C) 2002-2016 L<Guido Flohr|http://www.guido-flohr.net/>
+(L<mailto:guido.flohr@cantanea.com>), all rights reserved.  See the source
+code for details!code for details!
 
 =head1 SEE ALSO
 
