@@ -1,8 +1,8 @@
 #! /bin/false
 # vim: set autoindent shiftwidth=4 tabstop=4:
 
-# Conversion routines for ISO-8859-16.
-# Copyright (C) 2002-2015 Guido Flohr <guido.flohr@cantanea.com>,
+# Conversion routines for ISO-8859-8.
+# Copyright (C) 2002-2016 Guido Flohr <guido.flohr@cantanea.com>,
 # all rights reserved.
 
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-package Locale::RecodeData::ISO_8859_16;
+package Locale::RecodeData::ISO_8859_8;
 
 use strict;
 
@@ -187,101 +187,101 @@ my @to_ucs4 = (
     0x009e,
     0x009f,
     0x00a0,
-    0x0104,
-    0x0105,
-    0x0141,
-    0x20ac,
-    0x201e,
-    0x0160,
+    0xfffd,
+    0x00a2,
+    0x00a3,
+    0x00a4,
+    0x00a5,
+    0x00a6,
     0x00a7,
-    0x0161,
+    0x00a8,
     0x00a9,
-    0x0218,
+    0x00d7,
     0x00ab,
-    0x0179,
+    0x00ac,
     0x00ad,
-    0x017a,
-    0x017b,
+    0x00ae,
+    0x00af,
     0x00b0,
     0x00b1,
-    0x010c,
-    0x0142,
-    0x017d,
-    0x201d,
+    0x00b2,
+    0x00b3,
+    0x00b4,
+    0x00b5,
     0x00b6,
     0x00b7,
-    0x017e,
-    0x010d,
-    0x0219,
+    0x00b8,
+    0x00b9,
+    0x00f7,
     0x00bb,
-    0x0152,
-    0x0153,
-    0x0178,
-    0x017c,
-    0x00c0,
-    0x00c1,
-    0x00c2,
-    0x0102,
-    0x00c4,
-    0x0106,
-    0x00c6,
-    0x00c7,
-    0x00c8,
-    0x00c9,
-    0x00ca,
-    0x00cb,
-    0x00cc,
-    0x00cd,
-    0x00ce,
-    0x00cf,
-    0x0110,
-    0x0143,
-    0x00d2,
-    0x00d3,
-    0x00d4,
-    0x0150,
-    0x00d6,
-    0x015a,
-    0x0170,
-    0x00d9,
-    0x00da,
-    0x00db,
-    0x00dc,
-    0x0118,
-    0x021a,
-    0x00df,
-    0x00e0,
-    0x00e1,
-    0x00e2,
-    0x0103,
-    0x00e4,
-    0x0107,
-    0x00e6,
-    0x00e7,
-    0x00e8,
-    0x00e9,
-    0x00ea,
-    0x00eb,
-    0x00ec,
-    0x00ed,
-    0x00ee,
-    0x00ef,
-    0x0111,
-    0x0144,
-    0x00f2,
-    0x00f3,
-    0x00f4,
-    0x0151,
-    0x00f6,
-    0x015b,
-    0x0171,
-    0x00f9,
-    0x00fa,
-    0x00fb,
-    0x00fc,
-    0x0119,
-    0x021b,
-    0x00ff,
+    0x00bc,
+    0x00bd,
+    0x00be,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0xfffd,
+    0x2017,
+    0x05d0,
+    0x05d1,
+    0x05d2,
+    0x05d3,
+    0x05d4,
+    0x05d5,
+    0x05d6,
+    0x05d7,
+    0x05d8,
+    0x05d9,
+    0x05da,
+    0x05db,
+    0x05dc,
+    0x05dd,
+    0x05de,
+    0x05df,
+    0x05e0,
+    0x05e1,
+    0x05e2,
+    0x05e3,
+    0x05e4,
+    0x05e5,
+    0x05e6,
+    0x05e7,
+    0x05e8,
+    0x05e9,
+    0x05ea,
+    0xfffd,
+    0xfffd,
+    0x200e,
+    0x200f,
+    0xfffd,
 );
 
 my @to_utf8 = (
@@ -446,101 +446,101 @@ my @to_utf8 = (
     "\xc2\x9e",
     "\xc2\x9f",
     "\xc2\xa0",
-    "\xc4\x84",
-    "\xc4\x85",
-    "\xc5\x81",
-    "\xe2\x82\xac",
-    "\xe2\x80\x9e",
-    "\xc5\xa0",
+    "\xef\xbf\xbd",
+    "\xc2\xa2",
+    "\xc2\xa3",
+    "\xc2\xa4",
+    "\xc2\xa5",
+    "\xc2\xa6",
     "\xc2\xa7",
-    "\xc5\xa1",
+    "\xc2\xa8",
     "\xc2\xa9",
-    "\xc8\x98",
+    "\xc3\x97",
     "\xc2\xab",
-    "\xc5\xb9",
+    "\xc2\xac",
     "\xc2\xad",
-    "\xc5\xba",
-    "\xc5\xbb",
+    "\xc2\xae",
+    "\xc2\xaf",
     "\xc2\xb0",
     "\xc2\xb1",
-    "\xc4\x8c",
-    "\xc5\x82",
-    "\xc5\xbd",
-    "\xe2\x80\x9d",
+    "\xc2\xb2",
+    "\xc2\xb3",
+    "\xc2\xb4",
+    "\xc2\xb5",
     "\xc2\xb6",
     "\xc2\xb7",
-    "\xc5\xbe",
-    "\xc4\x8d",
-    "\xc8\x99",
+    "\xc2\xb8",
+    "\xc2\xb9",
+    "\xc3\xb7",
     "\xc2\xbb",
-    "\xc5\x92",
-    "\xc5\x93",
-    "\xc5\xb8",
-    "\xc5\xbc",
-    "\xc3\x80",
-    "\xc3\x81",
-    "\xc3\x82",
-    "\xc4\x82",
-    "\xc3\x84",
-    "\xc4\x86",
-    "\xc3\x86",
-    "\xc3\x87",
-    "\xc3\x88",
-    "\xc3\x89",
-    "\xc3\x8a",
-    "\xc3\x8b",
-    "\xc3\x8c",
-    "\xc3\x8d",
-    "\xc3\x8e",
-    "\xc3\x8f",
-    "\xc4\x90",
-    "\xc5\x83",
-    "\xc3\x92",
-    "\xc3\x93",
-    "\xc3\x94",
-    "\xc5\x90",
-    "\xc3\x96",
-    "\xc5\x9a",
-    "\xc5\xb0",
-    "\xc3\x99",
-    "\xc3\x9a",
-    "\xc3\x9b",
-    "\xc3\x9c",
-    "\xc4\x98",
-    "\xc8\x9a",
-    "\xc3\x9f",
-    "\xc3\xa0",
-    "\xc3\xa1",
-    "\xc3\xa2",
-    "\xc4\x83",
-    "\xc3\xa4",
-    "\xc4\x87",
-    "\xc3\xa6",
-    "\xc3\xa7",
-    "\xc3\xa8",
-    "\xc3\xa9",
-    "\xc3\xaa",
-    "\xc3\xab",
-    "\xc3\xac",
-    "\xc3\xad",
-    "\xc3\xae",
-    "\xc3\xaf",
-    "\xc4\x91",
-    "\xc5\x84",
-    "\xc3\xb2",
-    "\xc3\xb3",
-    "\xc3\xb4",
-    "\xc5\x91",
-    "\xc3\xb6",
-    "\xc5\x9b",
-    "\xc5\xb1",
-    "\xc3\xb9",
-    "\xc3\xba",
-    "\xc3\xbb",
-    "\xc3\xbc",
-    "\xc4\x99",
-    "\xc8\x9b",
-    "\xc3\xbf",
+    "\xc2\xbc",
+    "\xc2\xbd",
+    "\xc2\xbe",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xe2\x80\x97",
+    "\xd7\x90",
+    "\xd7\x91",
+    "\xd7\x92",
+    "\xd7\x93",
+    "\xd7\x94",
+    "\xd7\x95",
+    "\xd7\x96",
+    "\xd7\x97",
+    "\xd7\x98",
+    "\xd7\x99",
+    "\xd7\x9a",
+    "\xd7\x9b",
+    "\xd7\x9c",
+    "\xd7\x9d",
+    "\xd7\x9e",
+    "\xd7\x9f",
+    "\xd7\xa0",
+    "\xd7\xa1",
+    "\xd7\xa2",
+    "\xd7\xa3",
+    "\xd7\xa4",
+    "\xd7\xa5",
+    "\xd7\xa6",
+    "\xd7\xa7",
+    "\xd7\xa8",
+    "\xd7\xa9",
+    "\xd7\xaa",
+    "\xef\xbf\xbd",
+    "\xef\xbf\xbd",
+    "\xe2\x80\x8e",
+    "\xe2\x80\x8f",
+    "\xef\xbf\xbd",
 );
 
 my %from_ucs4 = (
@@ -705,101 +705,65 @@ my %from_ucs4 = (
     0x0000009e => "\x9e",
     0x0000009f => "\x9f",
     0x000000a0 => "\xa0",
+    0x000000a2 => "\xa2",
+    0x000000a3 => "\xa3",
+    0x000000a4 => "\xa4",
+    0x000000a5 => "\xa5",
+    0x000000a6 => "\xa6",
     0x000000a7 => "\xa7",
+    0x000000a8 => "\xa8",
     0x000000a9 => "\xa9",
     0x000000ab => "\xab",
+    0x000000ac => "\xac",
     0x000000ad => "\xad",
+    0x000000ae => "\xae",
+    0x000000af => "\xaf",
     0x000000b0 => "\xb0",
     0x000000b1 => "\xb1",
+    0x000000b2 => "\xb2",
+    0x000000b3 => "\xb3",
+    0x000000b4 => "\xb4",
+    0x000000b5 => "\xb5",
     0x000000b6 => "\xb6",
     0x000000b7 => "\xb7",
+    0x000000b8 => "\xb8",
+    0x000000b9 => "\xb9",
     0x000000bb => "\xbb",
-    0x000000c0 => "\xc0",
-    0x000000c1 => "\xc1",
-    0x000000c2 => "\xc2",
-    0x000000c4 => "\xc4",
-    0x000000c6 => "\xc6",
-    0x000000c7 => "\xc7",
-    0x000000c8 => "\xc8",
-    0x000000c9 => "\xc9",
-    0x000000ca => "\xca",
-    0x000000cb => "\xcb",
-    0x000000cc => "\xcc",
-    0x000000cd => "\xcd",
-    0x000000ce => "\xce",
-    0x000000cf => "\xcf",
-    0x000000d2 => "\xd2",
-    0x000000d3 => "\xd3",
-    0x000000d4 => "\xd4",
-    0x000000d6 => "\xd6",
-    0x000000d9 => "\xd9",
-    0x000000da => "\xda",
-    0x000000db => "\xdb",
-    0x000000dc => "\xdc",
-    0x000000df => "\xdf",
-    0x000000e0 => "\xe0",
-    0x000000e1 => "\xe1",
-    0x000000e2 => "\xe2",
-    0x000000e4 => "\xe4",
-    0x000000e6 => "\xe6",
-    0x000000e7 => "\xe7",
-    0x000000e8 => "\xe8",
-    0x000000e9 => "\xe9",
-    0x000000ea => "\xea",
-    0x000000eb => "\xeb",
-    0x000000ec => "\xec",
-    0x000000ed => "\xed",
-    0x000000ee => "\xee",
-    0x000000ef => "\xef",
-    0x000000f2 => "\xf2",
-    0x000000f3 => "\xf3",
-    0x000000f4 => "\xf4",
-    0x000000f6 => "\xf6",
-    0x000000f9 => "\xf9",
-    0x000000fa => "\xfa",
-    0x000000fb => "\xfb",
-    0x000000fc => "\xfc",
-    0x000000ff => "\xff",
-    0x00000102 => "\xc3",
-    0x00000103 => "\xe3",
-    0x00000104 => "\xa1",
-    0x00000105 => "\xa2",
-    0x00000106 => "\xc5",
-    0x00000107 => "\xe5",
-    0x0000010c => "\xb2",
-    0x0000010d => "\xb9",
-    0x00000110 => "\xd0",
-    0x00000111 => "\xf0",
-    0x00000118 => "\xdd",
-    0x00000119 => "\xfd",
-    0x00000141 => "\xa3",
-    0x00000142 => "\xb3",
-    0x00000143 => "\xd1",
-    0x00000144 => "\xf1",
-    0x00000150 => "\xd5",
-    0x00000151 => "\xf5",
-    0x00000152 => "\xbc",
-    0x00000153 => "\xbd",
-    0x0000015a => "\xd7",
-    0x0000015b => "\xf7",
-    0x00000160 => "\xa6",
-    0x00000161 => "\xa8",
-    0x00000170 => "\xd8",
-    0x00000171 => "\xf8",
-    0x00000178 => "\xbe",
-    0x00000179 => "\xac",
-    0x0000017a => "\xae",
-    0x0000017b => "\xaf",
-    0x0000017c => "\xbf",
-    0x0000017d => "\xb4",
-    0x0000017e => "\xb8",
-    0x00000218 => "\xaa",
-    0x00000219 => "\xba",
-    0x0000021a => "\xde",
-    0x0000021b => "\xfe",
-    0x0000201d => "\xb5",
-    0x0000201e => "\xa5",
-    0x000020ac => "\xa4",
+    0x000000bc => "\xbc",
+    0x000000bd => "\xbd",
+    0x000000be => "\xbe",
+    0x000000d7 => "\xaa",
+    0x000000f7 => "\xba",
+    0x000005d0 => "\xe0",
+    0x000005d1 => "\xe1",
+    0x000005d2 => "\xe2",
+    0x000005d3 => "\xe3",
+    0x000005d4 => "\xe4",
+    0x000005d5 => "\xe5",
+    0x000005d6 => "\xe6",
+    0x000005d7 => "\xe7",
+    0x000005d8 => "\xe8",
+    0x000005d9 => "\xe9",
+    0x000005da => "\xea",
+    0x000005db => "\xeb",
+    0x000005dc => "\xec",
+    0x000005dd => "\xed",
+    0x000005de => "\xee",
+    0x000005df => "\xef",
+    0x000005e0 => "\xf0",
+    0x000005e1 => "\xf1",
+    0x000005e2 => "\xf2",
+    0x000005e3 => "\xf3",
+    0x000005e4 => "\xf4",
+    0x000005e5 => "\xf5",
+    0x000005e6 => "\xf6",
+    0x000005e7 => "\xf7",
+    0x000005e8 => "\xf8",
+    0x000005e9 => "\xf9",
+    0x000005ea => "\xfa",
+    0x0000200e => "\xfd",
+    0x0000200f => "\xfe",
+    0x00002017 => "\xdf",
 );
 
 sub _recode
@@ -827,7 +791,7 @@ __END__
 
 =head1 NAME
 
-Locale::RecodeData::ISO_8859_16 - Conversion routines for ISO-8859-16
+Locale::RecodeData::ISO_8859_8 - Conversion routines for ISO-8859-8
 
 =head1 SYNOPSIS
 
@@ -836,16 +800,18 @@ This module is internal to libintl.  Do not use directly!
 =head1 DESCRIPTION
 
 This module is generated and contains the conversion tables and
-routines for ISO-8859-16.
+routines for ISO-8859-8.
 
 =head1 COMMENTS
 
 The following comments have been extracted from the original charmap:
 
- automatically generated from the charDB
- alias ISO-IR-226
- alias LATIN10
- alias L10
+ version: 1.0
+  source: ECMA registry
+ alias ISO-IR-138
+ alias ISO_8859-8:1988
+ alias ISO_8859-8
+ alias HEBREW
 
 Please note that aliases listed above are not necessarily valid!
 
@@ -857,38 +823,38 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
 
  Local | ISO-10646 | Description
 -------+-----------+-------------------------------------------------
-    00 |  00000000 | NULL
-    01 |  00000001 | START OF HEADING
-    02 |  00000002 | START OF TEXT
-    03 |  00000003 | END OF TEXT
-    04 |  00000004 | END OF TRANSMISSION
-    05 |  00000005 | ENQUIRY
-    06 |  00000006 | ACKNOWLEDGE
-    07 |  00000007 | BELL
-    08 |  00000008 | BACKSPACE
-    09 |  00000009 | HORIZONTAL TABULATION
-    0A |  0000000A | LINE FEED
-    0B |  0000000B | VERTICAL TABULATION
-    0C |  0000000C | FORM FEED
-    0D |  0000000D | CARRIAGE RETURN
-    0E |  0000000E | SHIFT OUT
-    0F |  0000000F | SHIFT IN
-    10 |  00000010 | DATA LINK ESCAPE
-    11 |  00000011 | DEVICE CONTROL ONE
-    12 |  00000012 | DEVICE CONTROL TWO
-    13 |  00000013 | DEVICE CONTROL THREE
-    14 |  00000014 | DEVICE CONTROL FOUR
-    15 |  00000015 | NEGATIVE ACKNOWLEDGE
-    16 |  00000016 | SYNCHRONOUS IDLE
-    17 |  00000017 | END OF TRANSMISSION BLOCK
-    18 |  00000018 | CANCEL
-    19 |  00000019 | END OF MEDIUM
-    1A |  0000001A | SUBSTITUTE
-    1B |  0000001B | ESCAPE
-    1C |  0000001C | FILE SEPARATOR
-    1D |  0000001D | GROUP SEPARATOR
-    1E |  0000001E | RECORD SEPARATOR
-    1F |  0000001F | UNIT SEPARATOR
+    00 |  00000000 | NULL (NUL)
+    01 |  00000001 | START OF HEADING (SOH)
+    02 |  00000002 | START OF TEXT (STX)
+    03 |  00000003 | END OF TEXT (ETX)
+    04 |  00000004 | END OF TRANSMISSION (EOT)
+    05 |  00000005 | ENQUIRY (ENQ)
+    06 |  00000006 | ACKNOWLEDGE (ACK)
+    07 |  00000007 | BELL (BEL)
+    08 |  00000008 | BACKSPACE (BS)
+    09 |  00000009 | CHARACTER TABULATION (HT)
+    0A |  0000000A | LINE FEED (LF)
+    0B |  0000000B | LINE TABULATION (VT)
+    0C |  0000000C | FORM FEED (FF)
+    0D |  0000000D | CARRIAGE RETURN (CR)
+    0E |  0000000E | SHIFT OUT (SO)
+    0F |  0000000F | SHIFT IN (SI)
+    10 |  00000010 | DATALINK ESCAPE (DLE)
+    11 |  00000011 | DEVICE CONTROL ONE (DC1)
+    12 |  00000012 | DEVICE CONTROL TWO (DC2)
+    13 |  00000013 | DEVICE CONTROL THREE (DC3)
+    14 |  00000014 | DEVICE CONTROL FOUR (DC4)
+    15 |  00000015 | NEGATIVE ACKNOWLEDGE (NAK)
+    16 |  00000016 | SYNCHRONOUS IDLE (SYN)
+    17 |  00000017 | END OF TRANSMISSION BLOCK (ETB)
+    18 |  00000018 | CANCEL (CAN)
+    19 |  00000019 | END OF MEDIUM (EM)
+    1A |  0000001A | SUBSTITUTE (SUB)
+    1B |  0000001B | ESCAPE (ESC)
+    1C |  0000001C | FILE SEPARATOR (IS4)
+    1D |  0000001D | GROUP SEPARATOR (IS3)
+    1E |  0000001E | RECORD SEPARATOR (IS2)
+    1F |  0000001F | UNIT SEPARATOR (IS1)
     20 |  00000020 | SPACE
     21 |  00000021 | EXCLAMATION MARK
     22 |  00000022 | QUOTATION MARK
@@ -984,7 +950,7 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     7C |  0000007C | VERTICAL LINE
     7D |  0000007D | RIGHT CURLY BRACKET
     7E |  0000007E | TILDE
-    7F |  0000007F | DELETE
+    7F |  0000007F | DELETE (DEL)
     80 |  00000080 | PADDING CHARACTER (PAD)
     81 |  00000081 | HIGH OCTET PRESET (HOP)
     82 |  00000082 | BREAK PERMITTED HERE (BPH)
@@ -1018,107 +984,72 @@ All character codes are in hexadecimal.  Please read 'ISO-10646' as
     9E |  0000009E | PRIVACY MESSAGE (PM)
     9F |  0000009F | APPLICATION PROGRAM COMMAND (APC)
     A0 |  000000A0 | NO-BREAK SPACE
-    A1 |  00000104 | LATIN CAPITAL LETTER A WITH OGONEK
-    A2 |  00000105 | LATIN SMALL LETTER A WITH OGONEK
-    A3 |  00000141 | LATIN CAPITAL LETTER L WITH STROKE
-    A4 |  000020AC | EURO SIGN
-    A5 |  0000201E | DOUBLE LOW-9 QUOTATION MARK
-    A6 |  00000160 | LATIN CAPITAL LETTER S WITH CARON
+    A2 |  000000A2 | CENT SIGN
+    A3 |  000000A3 | POUND SIGN
+    A4 |  000000A4 | CURRENCY SIGN
+    A5 |  000000A5 | YEN SIGN
+    A6 |  000000A6 | BROKEN BAR
     A7 |  000000A7 | SECTION SIGN
-    A8 |  00000161 | LATIN SMALL LETTER S WITH CARON
+    A8 |  000000A8 | DIAERESIS
     A9 |  000000A9 | COPYRIGHT SIGN
-    AA |  00000218 | LATIN CAPITAL LETTER S WITH COMMA BELOW
+    AA |  000000D7 | MULTIPLICATION SIGN
     AB |  000000AB | LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
-    AC |  00000179 | LATIN CAPITAL LETTER Z WITH ACUTE
+    AC |  000000AC | NOT SIGN
     AD |  000000AD | SOFT HYPHEN
-    AE |  0000017A | LATIN SMALL LETTER Z WITH ACUTE
-    AF |  0000017B | LATIN CAPITAL LETTER Z WITH DOT ABOVE
+    AE |  000000AE | REGISTERED SIGN
+    AF |  000000AF | MACRON
     B0 |  000000B0 | DEGREE SIGN
     B1 |  000000B1 | PLUS-MINUS SIGN
-    B2 |  0000010C | LATIN CAPITAL LETTER C WITH CARON
-    B3 |  00000142 | LATIN SMALL LETTER L WITH STROKE
-    B4 |  0000017D | LATIN CAPITAL LETTER Z WITH CARON
-    B5 |  0000201D | RIGHT DOUBLE QUOTATION MARK
+    B2 |  000000B2 | SUPERSCRIPT TWO
+    B3 |  000000B3 | SUPERSCRIPT THREE
+    B4 |  000000B4 | ACUTE ACCENT
+    B5 |  000000B5 | MICRO SIGN
     B6 |  000000B6 | PILCROW SIGN
     B7 |  000000B7 | MIDDLE DOT
-    B8 |  0000017E | LATIN SMALL LETTER Z WITH CARON
-    B9 |  0000010D | LATIN SMALL LETTER C WITH CARON
-    BA |  00000219 | LATIN SMALL LETTER S WITH COMMA BELOW
+    B8 |  000000B8 | CEDILLA
+    B9 |  000000B9 | SUPERSCRIPT ONE
+    BA |  000000F7 | DIVISION SIGN
     BB |  000000BB | RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
-    BC |  00000152 | LATIN CAPITAL LIGATURE OE
-    BD |  00000153 | LATIN SMALL LIGATURE OE
-    BE |  00000178 | LATIN CAPITAL LETTER Y WITH DIAERESIS
-    BF |  0000017C | LATIN SMALL LETTER Z WITH DOT ABOVE
-    C0 |  000000C0 | LATIN CAPITAL LETTER A WITH GRAVE
-    C1 |  000000C1 | LATIN CAPITAL LETTER A WITH ACUTE
-    C2 |  000000C2 | LATIN CAPITAL LETTER A WITH CIRCUMFLEX
-    C3 |  00000102 | LATIN CAPITAL LETTER A WITH BREVE
-    C4 |  000000C4 | LATIN CAPITAL LETTER A WITH DIAERESIS
-    C5 |  00000106 | LATIN CAPITAL LETTER C WITH ACUTE
-    C6 |  000000C6 | LATIN CAPITAL LETTER AE
-    C7 |  000000C7 | LATIN CAPITAL LETTER C WITH CEDILLA
-    C8 |  000000C8 | LATIN CAPITAL LETTER E WITH GRAVE
-    C9 |  000000C9 | LATIN CAPITAL LETTER E WITH ACUTE
-    CA |  000000CA | LATIN CAPITAL LETTER E WITH CIRCUMFLEX
-    CB |  000000CB | LATIN CAPITAL LETTER E WITH DIAERESIS
-    CC |  000000CC | LATIN CAPITAL LETTER I WITH GRAVE
-    CD |  000000CD | LATIN CAPITAL LETTER I WITH ACUTE
-    CE |  000000CE | LATIN CAPITAL LETTER I WITH CIRCUMFLEX
-    CF |  000000CF | LATIN CAPITAL LETTER I WITH DIAERESIS
-    D0 |  00000110 | LATIN CAPITAL LETTER D WITH STROKE
-    D1 |  00000143 | LATIN CAPITAL LETTER N WITH ACUTE
-    D2 |  000000D2 | LATIN CAPITAL LETTER O WITH GRAVE
-    D3 |  000000D3 | LATIN CAPITAL LETTER O WITH ACUTE
-    D4 |  000000D4 | LATIN CAPITAL LETTER O WITH CIRCUMFLEX
-    D5 |  00000150 | LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
-    D6 |  000000D6 | LATIN CAPITAL LETTER O WITH DIAERESIS
-    D7 |  0000015A | LATIN CAPITAL LETTER S WITH ACUTE
-    D8 |  00000170 | LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
-    D9 |  000000D9 | LATIN CAPITAL LETTER U WITH GRAVE
-    DA |  000000DA | LATIN CAPITAL LETTER U WITH ACUTE
-    DB |  000000DB | LATIN CAPITAL LETTER U WITH CIRCUMFLEX
-    DC |  000000DC | LATIN CAPITAL LETTER U WITH DIAERESIS
-    DD |  00000118 | LATIN CAPITAL LETTER E WITH OGONEK
-    DE |  0000021A | LATIN CAPITAL LETTER T WITH COMMA BELOW
-    DF |  000000DF | LATIN SMALL LETTER SHARP S
-    E0 |  000000E0 | LATIN SMALL LETTER A WITH GRAVE
-    E1 |  000000E1 | LATIN SMALL LETTER A WITH ACUTE
-    E2 |  000000E2 | LATIN SMALL LETTER A WITH CIRCUMFLEX
-    E3 |  00000103 | LATIN SMALL LETTER A WITH BREVE
-    E4 |  000000E4 | LATIN SMALL LETTER A WITH DIAERESIS
-    E5 |  00000107 | LATIN SMALL LETTER C WITH ACUTE
-    E6 |  000000E6 | LATIN SMALL LETTER AE
-    E7 |  000000E7 | LATIN SMALL LETTER C WITH CEDILLA
-    E8 |  000000E8 | LATIN SMALL LETTER E WITH GRAVE
-    E9 |  000000E9 | LATIN SMALL LETTER E WITH ACUTE
-    EA |  000000EA | LATIN SMALL LETTER E WITH CIRCUMFLEX
-    EB |  000000EB | LATIN SMALL LETTER E WITH DIAERESIS
-    EC |  000000EC | LATIN SMALL LETTER I WITH GRAVE
-    ED |  000000ED | LATIN SMALL LETTER I WITH ACUTE
-    EE |  000000EE | LATIN SMALL LETTER I WITH CIRCUMFLEX
-    EF |  000000EF | LATIN SMALL LETTER I WITH DIAERESIS
-    F0 |  00000111 | LATIN SMALL LETTER D WITH STROKE
-    F1 |  00000144 | LATIN SMALL LETTER N WITH ACUTE
-    F2 |  000000F2 | LATIN SMALL LETTER O WITH GRAVE
-    F3 |  000000F3 | LATIN SMALL LETTER O WITH ACUTE
-    F4 |  000000F4 | LATIN SMALL LETTER O WITH CIRCUMFLEX
-    F5 |  00000151 | LATIN SMALL LETTER O WITH DOUBLE ACUTE
-    F6 |  000000F6 | LATIN SMALL LETTER O WITH DIAERESIS
-    F7 |  0000015B | LATIN SMALL LETTER S WITH ACUTE
-    F8 |  00000171 | LATIN SMALL LETTER U WITH DOUBLE ACUTE
-    F9 |  000000F9 | LATIN SMALL LETTER U WITH GRAVE
-    FA |  000000FA | LATIN SMALL LETTER U WITH ACUTE
-    FB |  000000FB | LATIN SMALL LETTER U WITH CIRCUMFLEX
-    FC |  000000FC | LATIN SMALL LETTER U WITH DIAERESIS
-    FD |  00000119 | LATIN SMALL LETTER E WITH OGONEK
-    FE |  0000021B | LATIN SMALL LETTER T WITH COMMA BELOW
-    FF |  000000FF | LATIN SMALL LETTER Y WITH DIAERESIS
+    BC |  000000BC | VULGAR FRACTION ONE QUARTER
+    BD |  000000BD | VULGAR FRACTION ONE HALF
+    BE |  000000BE | VULGAR FRACTION THREE QUARTERS
+    DF |  00002017 | DOUBLE LOW LINE
+    E0 |  000005D0 | HEBREW LETTER ALEF
+    E1 |  000005D1 | HEBREW LETTER BET
+    E2 |  000005D2 | HEBREW LETTER GIMEL
+    E3 |  000005D3 | HEBREW LETTER DALET
+    E4 |  000005D4 | HEBREW LETTER HE
+    E5 |  000005D5 | HEBREW LETTER VAV
+    E6 |  000005D6 | HEBREW LETTER ZAYIN
+    E7 |  000005D7 | HEBREW LETTER HET
+    E8 |  000005D8 | HEBREW LETTER TET
+    E9 |  000005D9 | HEBREW LETTER YOD
+    EA |  000005DA | HEBREW LETTER FINAL KAF
+    EB |  000005DB | HEBREW LETTER KAF
+    EC |  000005DC | HEBREW LETTER LAMED
+    ED |  000005DD | HEBREW LETTER FINAL MEM
+    EE |  000005DE | HEBREW LETTER MEM
+    EF |  000005DF | HEBREW LETTER FINAL NUN
+    F0 |  000005E0 | HEBREW LETTER NUN
+    F1 |  000005E1 | HEBREW LETTER SAMEKH
+    F2 |  000005E2 | HEBREW LETTER AYIN
+    F3 |  000005E3 | HEBREW LETTER FINAL PE
+    F4 |  000005E4 | HEBREW LETTER PE
+    F5 |  000005E5 | HEBREW LETTER FINAL TSADI
+    F6 |  000005E6 | HEBREW LETTER TSADI
+    F7 |  000005E7 | HEBREW LETTER QOF
+    F8 |  000005E8 | HEBREW LETTER RESH
+    F9 |  000005E9 | HEBREW LETTER SHIN
+    FA |  000005EA | HEBREW LETTER TAV
+    FD |  0000200E | LEFT-TO-RIGHT MARK
+    FE |  0000200F | RIGHT-TO-LEFT MARK
 
 
 =head1 AUTHOR
 
-Copyright (C) 2002-2015, Guido Flohr E<lt>guido.flohr@cantanea.comE<gt>, all
-rights reserved.  See the source code for details.
+Copyright (C) 2002-2016 L<Guido Flohr|http://www.guido-flohr.net/>
+(L<mailto:guido.flohr@cantanea.com>), all rights reserved.  See the source
+code for details!code for details!
 
 =head1 SEE ALSO
 
